@@ -51,6 +51,6 @@ int main(int argc, char *argv[])
         QApplication::beep();
         QMessageBox::critical(0, QString::null,
                               QApplication::tr("You must run this program as root."));
-        return 1;
+        return EXIT_FAILURE;
     }
 }
